summaryrefslogtreecommitdiff
path: root/src/mongo/client/dbclient_connection.h
diff options
context:
space:
mode:
authorLucas de Castro Borges <lucas@gnuabordo.com.br>2025-02-14 14:26:38 -0300
committerLucas de Castro Borges <lucas@gnuabordo.com.br>2025-02-14 14:26:38 -0300
commit294bc6ecabf14c09c9bc8644704921dcf97cb44e (patch)
tree279b1e0bab53901a1647ac63c1c724f0f789a663 /src/mongo/client/dbclient_connection.h
parent70be7c27a251621187a1de533462ae2bb1e3bd39 (diff)
parent1e917fd798aa25b7066d4b414b51184f13d5a092 (diff)
Update upstream source from tag 'upstream/6.0.10'debian/6.0.10-1
Update to upstream version '6.0.10' with Debian dir 2d176fa254eee97b139f712fec5709641335a8c3
Diffstat (limited to 'src/mongo/client/dbclient_connection.h')
-rw-r--r--src/mongo/client/dbclient_connection.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/client/dbclient_connection.h b/src/mongo/client/dbclient_connection.h
index 9187852758d..02465fa8387 100644
--- a/src/mongo/client/dbclient_connection.h
+++ b/src/mongo/client/dbclient_connection.h
@@ -76,13 +76,13 @@ class DBClientCursorBatchIterator;
class DBClientConnection : public DBClientBase {
public:
/**
* A hook used to validate the reply of an 'isMaster' command during connection. If the hook
* returns a non-OK Status, the DBClientConnection object will disconnect from the remote
* server. This function must not throw - it can only indicate failure by returning a non-OK
* status.
*/
using HandshakeValidationHook =
- std::function<Status(const executor::RemoteCommandResponse& isMasterReply)>;
+ std::function<Status(const executor::RemoteCommandResponse& helloReply)>;
/**
@param _autoReconnect if true, automatically reconnect on a connection failure
@@ -125,8 +125,8 @@ public:
boost::optional<TransientSSLParams> transientSSLParams);
/**
* This version of connect does not run 'isMaster' after creating a TCP connection to the
* remote host. This method should be used only when calling 'isMaster' would create a deadlock,
* such as in 'isSelf'.
*
* @param server The server to connect to.
@@ -76,13 +76,13 @@ class DBClientCursorBatchIterator;
public:
/**
- * A hook used to validate the reply of an 'isMaster' command during connection. If the hook
+ * A hook used to validate the reply of a "hello" command during connection. If the hook
* returns a non-OK Status, the DBClientConnection object will disconnect from the remote
* server. This function must not throw - it can only indicate failure by returning a non-OK
@@ -125,8 +125,8 @@ public:
boost::optional<TransientSSLParams> transientSSLParams);
/**
- * This version of connect does not run 'isMaster' after creating a TCP connection to the
- * remote host. This method should be used only when calling 'isMaster' would create a deadlock,
+ * This version of connect does not run "hello" after creating a TCP connection to the
+ * remote host. This method should be used only when calling "hello" would create a deadlock,
* such as in 'isSelf'.
*